# TeleLib

A Telegram Library that uses Python to generate Wrappers on Any language you like :)

---

## Usage

---

## installation

```bash
pip install telelib
```

or if you're on node

```bash
npm install @TeleLib/TeleLib
# OR
yarn add @TeleLib/TeleLib
```

## more info

- for more examples visit [examples](/examples)
- for better and more detailed documentation visit [docs](/docs)

## issues / bugs / suggestions ?

fix it and open a Pull request :)

don't forget to follow our [contribution rules](/CONTRIBUTING.md)

## contributors

- [ReloadLife](https://github.com/reloadlife) - Maintainer

</br>

- [Your name can be here :)](/CONTRIBUTING.md)

----

## known bugs

- fix workflow to publish codes to pypi.
- fix workflow to publish codes on npm.

## todo list

- [x] Write Code that write code for methods and types.
- [ ] Write Full Documentation
- [ ] add Helper methods
- [ ] Add More examples
- [ ] Write Interfaces for all Message types, classes, methods.
- [ ] Add Support for Webhooks
- [ ] Implement TelegramPassport related methods
- [ ] Add MTProto and TDLib Wrapper.
- [ ] Clean up and optimize the code.

## Supported Languages

- [x] TypeScript
- [x] Python
- [ ] PHP
- [ ] Lua
- [ ] Ruby
- [ ] Go
- [ ] Perl
- [ ] Julia
